from Products.Archetypes.public import *

try:
    from Products.ATContentTypes.content.file import ATFile, ATFileSchema
except ImportError:
    # For ATCT 0.2 compatibility
    from Products.ATContentTypes.types.ATFile import ATFile
    from Products.ATContentTypes.types.schemata import ATFileSchema

try :
    from Products.CMFCore import permissions
except ImportError:
    # For CMF 1.4 compatibility
    from Products.CMFCore import CMFCorePermissions
    permissions = CMFCorePermissions

from Products.CMFCore.utils import getToolByName
from AccessControl import ClassSecurityInfo
from config import *


schema = ATFileSchema + Schema((

    TextField('body',
              required = False,
              searchable = True,
              widget=RichWidget(description='Explanatory text',
                                description_msgid ="desc_description",
                                label='Text',
                                label_msgid ='label_description',                                
                                i18n_domain = 'ATGeogebra',
                                rows=25),

             ),


    StringField('width',
                 required = False,
                 searchable = False,
                 default = '100%',
                 widget=StringWidget(label ='Width', modes= ('view','edit',),
                                      label_msgid ='label_width',
                                      description = 'Width of the applet. Pixels or %',
                                      description_msgid ="desc_width",
                                      i18n_domain='ATGeogebra'),
                 ),
    
    StringField('height',
                 required = False,
                 searchable = False,
                 default = '100%',
                 widget=StringWidget(label ='Height', modes= ('view','edit'),
                                      label_msgid ='label_height',
                                      description = 'Height of the applet. Pixels or %',
                                      description_msgid ="desc_height",
                                      i18n_domain='ATGeogebra'),
                 ),

    ))


class ATGeogebra(ATFile):
    """A Geogebra activity file"""
    
    schema = schema
    archetype_name = 'Geogebra Activity File'
    meta_type = 'GeogebraFile'
    portal_type = 'GeogebraFile'
    content_icon = 'geogebra_applet.gif'
    immediate_view = 'geogebrafile_view'
    default_view   = 'geogebrafile_view'
    suppl_views    = ()
    typeDescription= "Geogebra Activity File"
    typeDescMsgId  = 'description_edit_geogebra_file'
    assocFileExt   = ('ggb',)
    
    global_allow = True

    security = ClassSecurityInfo()

    security.declareProtected(permissions.ModifyPortalContent, 'setFile')
    
    def setFile(self, value, **kwargs):
        """Saves file and stores geogebra applet informations (size etc)"""
        ATFile.setFile(self, value, **kwargs)

    security.declarePublic('getIcon')
    def getIcon(self, relative_to_portal=0):
        """Returns icon for Geogebra file"""
        icon = self.content_icon

        if relative_to_portal:
            return icon
        else:
            utool = getToolByName( self, 'portal_url' )
            # Relative to REQUEST['BASEPATH1']
            res = utool(relative=1) + '/' + icon
            while res[:1] == '/':
                res = res[1:]
            return res

registerType(ATGeogebra)
